"use client"
import React, { useState, useEffect, useRef } from "react";
interface GlossaryPopupProps {
    term: string;
    definition: string;
    }

const GlossaryPopup: React.FC<GlossaryPopupProps> = ({ term, definition }) => {
    const [isOpen, setIsOpen] = useState(false);
    const popupRef = useRef<HTMLDivElement>(null);
    useEffect(() => {
        const handleClickOutside = (event: MouseEvent) => {
            if (popupRef.current && !popupRef.current.contains(event.target as Node)) {
                setIsOpen(false);
            }
        }
        document.addEventListener("mousedown", handleClickOutside);
    
        return() => {
            document.removeEventListener("mousedown", handleClickOutside);
        }
    }, []);
    return (
    <span className="relative">
        {term}
        <sup
            className="text-blue-600 cursor-pointer"
            onClick={() => setIsOpen(!isOpen)}
            >
                [-]
        </sup>
        {isOpen && (
            <div
                ref={popupRef}
                className="absolute left-0 top-full mt-1 w-64 bg-white border border-gray-300 rounded shadow-lg p-1 z-50"
            >
                <p className="text-gray-900 font-bold px-2 m-2">{term}</p>
                <p className="text-gray-700 text-sm px-2 m-2">{definition}</p>
            </div>
        )}
    </span>
    )
}

export default GlossaryPopup;
    